@@ -10,7 +10,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .memory_cache import MemoryCache
 from .database import Database
 from .download_cache import DownloadCache
 from .ensembl_release import EnsemblRelease, cached_release
@@ -41,7 +40,6 @@ from .version import __version__
 
 __all__ = [
     "__version__",
-    "MemoryCache",
     "DownloadCache",
     "Database",
     "EnsemblRelease",
